@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-instances
 version: 3.3.1
-id: vector-instances-3.3.1-4d00e419b027b3eb49bf222371e6664c
-key: vecto_J5YdrE0ERyOBjQDEHL0l31
+id: vector-instances-3.3.1-a2708c400d293b86fcc466b57d4d7ffa
+key: vecto_3Wl7zBiGuCaFFuJ2BLZv0D
 license: BSD3
 maintainer: ekmett@gmail.com
 homepage: http://github.com/ekmett/vector-instances
@@ -17,14 +17,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-instances-3.3.1
-hs-libraries: HSvector-instances-3.3.1-J5YdrE0ERyOBjQDEHL0l31
+hs-libraries: HSvector-instances-3.3.1-3Wl7zBiGuCaFFuJ2BLZv0D
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-eb230ef163a26fe6410daceeb92d736a
-    keys-3.11-b9b33b5e3167a9e52eac8339532d5b75
-    pointed-5-a178eacce938ed1efae7fa2245a617f4
-    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    comonad-5-9b3bac8b2740903020c84a0c2eebf7b2
+    keys-3.11-38bd61cc2ce69a0a026768a2d22f358f
+    pointed-5-e46e40cb3451f7a243714c9db1dacd47
+    semigroupoids-5.0.1-8eb2d2c8f0f0def85cbb7c35538a003a
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
 haddock-html: /usr/share/doc/haskell-vector-instances/html
